==> lzlla-0.0.7.tar.gz: lzlla-0.0.7/lzlla/guide.py <==
import time


def guide():
    print('======================================================================')
    print('欢迎下载我的第三方模块0.0.7版')
    print('Welcome to download my third-party module-0.0.7')
    time.sleep(2)
    print('==========================================================================================')
    print('本模块是由多人连个完成的模块')
    print('==========================================================================================')
    print('author/name/connecting_point/connecting_point_tester')
    print('请输入需要查询的函数 ')
    print('Please enter the function that you want to query')
    guide_to_print = input('')
    print('==========================================================================================')
    print('正在查询')
    print('==========================================================================================')
    if guide_to_print == 'author':
        print('这是一个介绍开发者的函数，用法如下')
        print('This is a function that introduces author and is used as follows')
        print('==========================================================================================')
        print('guide.guide()')
        print('==========================================================================================')
    elif guide_to_print == 'name':
        print('这是一个名字检测函数,用法如下')
        print('This is a name detection function and is used as follows')
        print('==========================================================================================')
        print('name.name()')
        print('==========================================================================================')
    elif guide_to_print == 'connecting_point':
        print('这是一个连点器,用法如下')
        print('this is a connecting point and is used as follows')
        print('==========================================================================================')
        print('connecting_point.connecting_point()')
        print('==========================================================================================')
    elif guide_to_print == 'connecting_point_tester':
        print('这是一个连点器测试器,用法如下')
        print('This is a connecting point tester and is used as follows')
        print('==========================================================================================')
        print('connecting_point_tester.connecting_point_tester()')
        print('==========================================================================================')
    else:
        print('本模块暂时没有这个功能，尽情期待！')
        print('This module does not have this function for the time being, so enjoy it!')
        print('==========================================================================================')
    print('本模块将发展为很会玩的模块')
    print('This module will evolve into a very playable module')
    print('==========================================================================================')
    time.sleep(2)
    print('如果你有好的提议请联系开发者邮箱：liuniandexiaohuo@qq.com')
    print('If you have a good proposal, please contact the developer email: liuniandexiaohuo@qq.com')
    print('==========================================================================================')
    time.sleep(3)
    print('我会在看到邮件后第一时间回复你')
    print('I will reply to you as soon as I see the email')
    print('==========================================================================================')

==> lzlla-0.4.1.tar.gz: lzlla-0.4.1/lzlla/guide.py <==
import time


def guide():
    """
    import lzlla import guide
    guide.guide()
    """
    print('======================================================================')
    print('欢迎下载我的第三方模块0.3.0版')
    print('Welcome to download my third-party module-0.4.1')
    time.sleep(2)
    print('==========================================================================================')
    print('本模块是由多人联合完成的模块')
    print('==========================================================================================')
    print('author/name/connecting_points/connecting_points_tester/information_bombardment/QR')
    print('请输入需要查询的函数 ')
    print('Please enter the function that you want to query')
    guide_to_print = input('')
    print('==========================================================================================')
    print('正在查询')
    print('==========================================================================================')
    if guide_to_print == 'author':
        print('这是一个介绍开发者的函数，用法如下')
        print('This is a function that introduces author and is used as follows')
        print('==========================================================================================')
        print('author.author()')
        print('==========================================================================================')
    elif guide_to_print == 'name':
        print('这是一个名字检测函数,用法如下')
        print('This is a name detection function and is used as follows')
        print('==========================================================================================')
        print('name.name()')
        print('==========================================================================================')
        time.sleep(3)
    elif guide_to_print == 'connecting_points':
        print('这是一个连点器,用法如下')
        print('this is a connecting point and is used as follows')
        print('==========================================================================================')
        print('connecting_points.connecting_points()')
        print('==========================================================================================')
        time.sleep(3)
    elif guide_to_print == 'connecting_points_tester':
        print('这是一个连点器测试器,用法如下')
        print('This is a connecting point tester and is used as follows')
        print('==========================================================================================')
        print('connecting_points_tester.connecting_points_tester()')
        print('==========================================================================================')
        time.sleep(3)
    elif guide_to_print == 'information_bombardment':
        print('这是一个社交软件信息轰炸器，用法如下')
        print('This is a social software information bomberand is used as follows')
        print('==========================================================================================')
        print('如果你用的语言是中文请用：')
        print('information_bombardment.information_bombardment_Chinese()')
        print('')
        print('If you speak English,please use:')
        print('information_bombardment.information_bombardment_English()')
        print('==========================================================================================')
        time.sleep(3)
    elif guide_to_print == 'QR':
        print('这是一个二维码生成器，用法如下')
        print('This is a QR code generator')
        print('==========================================================================================')
        print('QR.QR()')
    else:
        print('本模块暂时没有这个功能，尽情期待！')
        print('This module does not have this function for the time being, so enjoy it!')
        print('==========================================================================================')
        time.sleep(3)
    print('')
    print('')
    print('==========================================================================================')
    print('==========================================================================================')
    print('==========================================================================================')
    print('==========================================================================================')
    print('本模块将发展为很会玩的模块')
    print('This module will evolve into a very playable module')
    print('==========================================================================================')
    time.sleep(2)
    print('如果你有好的提议请联系开发者邮箱：liuniandexiaohuo@qq.com')
    print('If you have a good proposal, please contact the developer email: liuniandexiaohuo@qq.com')
    print('==========================================================================================')
    time.sleep(3)
    print('我会在看到邮件后第一时间回复你')
    print('I will reply to you as soon as I see the email')
    print('==========================================================================================')
